"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
var TNSDOMMatrix_1 = require("./TNSDOMMatrix");
var canvas_plugin_common_1 = require("./canvas-plugin.common");
var TNSCanvasRenderingContext2D_1 = require("./TNSCanvasRenderingContext2D");
var TNSWebGLRenderingContext_1 = require("./TNSWebGLRenderingContext");
var TNSWebGL2RenderingContext_1 = require("./TNSWebGL2RenderingContext");
var app = require("@nativescript/core/application");
function createSVGMatrix() {
    return new TNSDOMMatrix_1.TNSDOMMatrix(com.github.triniwiz.canvas.CanvasView.createSVGMatrix());
}
exports.createSVGMatrix = createSVGMatrix;
__export(require("./canvas-plugin.common"));
var TNSCanvas = (function (_super) {
    __extends(TNSCanvas, _super);
    function TNSCanvas() {
        var _this = _super.call(this) || this;
        _this._ready = false;
        _this._didPause = false;
        var activity = app.android.foregroundActivity || app.android.startActivity;
        _this._canvas = new com.github.triniwiz.canvas.CanvasView(activity, false);
        return _this;
    }
    Object.defineProperty(TNSCanvas.prototype, "android", {
        get: function () {
            return this._canvas;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvas.prototype, "clientWidth", {
        get: function () {
            return this.width;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvas.prototype, "clientHeight", {
        get: function () {
            return this.height;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvas.prototype, "width", {
        get: function () {
            if (this.getMeasuredWidth() > 0) {
                return this.getMeasuredWidth();
            }
            var width = this._canvas.getWidth();
            if (width === 0) {
                var rootParams = this._canvas.getLayoutParams();
                if (rootParams) {
                    return rootParams.width;
                }
            }
            return width;
        },
        set: function (value) {
            this.style.width = value;
            if (this._isCustom) {
                this._layoutNative();
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvas.prototype, "height", {
        get: function () {
            if (this.getMeasuredHeight() > 0) {
                return this.getMeasuredHeight();
            }
            var height = this._canvas.getHeight();
            if (height === 0) {
                var rootParams = this._canvas.getLayoutParams();
                if (rootParams) {
                    return rootParams.height;
                }
            }
            return height;
        },
        set: function (value) {
            this.style.height = value;
            if (this._isCustom) {
                this._layoutNative();
            }
        },
        enumerable: true,
        configurable: true
    });
    TNSCanvas.createCustomView = function () {
        var canvas = new TNSCanvas();
        canvas._isCustom = true;
        canvas.width = 300;
        canvas.height = 150;
        return canvas;
    };
    TNSCanvas.prototype.createNativeView = function () {
        return this._canvas;
    };
    TNSCanvas.prototype.initNativeView = function () {
        _super.prototype.initNativeView.call(this);
        var ref = new WeakRef(this);
        this._canvas.setListener(new com.github.triniwiz.canvas.CanvasView.Listener({
            contextReady: function () {
                var owner = ref.get();
                if (owner && !owner._ready) {
                    owner._ready = true;
                    owner._readyEvent();
                }
            },
        }));
    };
    TNSCanvas.prototype.onUnloaded = function () {
        this._didPause = true;
        if (this._canvas) {
            this._canvas.onPause();
        }
        _super.prototype.onUnloaded.call(this);
    };
    TNSCanvas.prototype.onLoaded = function () {
        _super.prototype.onLoaded.call(this);
        if (this._didPause) {
            this._didPause = false;
            if (this._canvas) {
                this._canvas.onResume();
            }
        }
    };
    TNSCanvas.prototype.flush = function () {
        if (this._didPause) {
            return;
        }
        this._canvas.flush();
    };
    TNSCanvas.prototype.disposeNativeView = function () {
        this.off('touch, pan', this._touchEvents);
        _super.prototype.disposeNativeView.call(this);
    };
    TNSCanvas.prototype.toDataURL = function (type, encoderOptions) {
        if (type === void 0) { type = 'png'; }
        if (encoderOptions === void 0) { encoderOptions = 0.92; }
        return this.android.toDataURL(type, encoderOptions);
    };
    TNSCanvas.prototype._layoutNative = function () {
        if (!this.parent) {
            if ((typeof this.width === 'string' && this.width.indexOf('%')) ||
                (typeof this.height === 'string' && this.height.indexOf('%'))) {
                return;
            }
            if (!this._isCustom) {
                return;
            }
            var size = this._realSize;
            var rootParams = this._canvas.getLayoutParams();
            if (rootParams &&
                (size.width || 0) === rootParams.width &&
                (size.height || 0) === rootParams.height) {
                return;
            }
            if ((size.width || 0) !== 0 && (size.height || 0) !== 0) {
                if (!rootParams) {
                    rootParams = new android.widget.FrameLayout.LayoutParams(0, 0);
                }
                rootParams.width = size.width;
                rootParams.height = size.height;
                var surfaceParams = this._canvas.getSurface().getLayoutParams();
                if (!surfaceParams) {
                    surfaceParams = new android.widget.FrameLayout.LayoutParams(0, 0);
                }
                surfaceParams.width = size.width;
                surfaceParams.height = size.height;
                this._canvas.setLayoutParams(rootParams);
                this._canvas.getSurface().setLayoutParams(surfaceParams);
                var w = android.view.View.MeasureSpec.makeMeasureSpec(size.width, android.view.View.MeasureSpec.EXACTLY);
                var h = android.view.View.MeasureSpec.makeMeasureSpec(size.height, android.view.View.MeasureSpec.EXACTLY);
                this._canvas.measure(w, h);
                this._canvas.layout(0, 0, size.width || 0, size.height || 0);
            }
        }
    };
    TNSCanvas.prototype.getContext = function (type, options) {
        var glOpts = Object.assign({}, {
            alpha: true,
            antialias: true,
            depth: true,
            failIfMajorPerformanceCaveat: false,
            powerPreference: "default",
            premultipliedAlpha: true,
            preserveDrawingBuffer: false,
            stencil: false,
            desynchronized: false
        }, options || {});
        var canvasOpts = Object.assign({}, {
            alpha: true
        }, options || {});
        var getNativeOptions = function (options) {
            var opts = new java.util.HashMap();
            Object.keys(options).forEach(function (key) {
                var val = options[key];
                if (typeof val === "boolean") {
                    opts.put(key, java.lang.Boolean.valueOf(String(val)));
                }
                else {
                    opts.put(key, val);
                }
            });
            return opts;
        };
        if (typeof type === 'string') {
            if (type === '2d') {
                if (this._webglContext || this._webgl2Context) {
                    return null;
                }
                if (!this._2dContext) {
                    this._2dContext = new TNSCanvasRenderingContext2D_1.TNSCanvasRenderingContext2D(this._canvas.getContext(type, getNativeOptions(canvasOpts)));
                    this._2dContext._canvas = this;
                }
                else {
                    this._canvas.getContext(type, getNativeOptions(canvasOpts));
                }
                this._2dContext._type = '2d';
                return this._2dContext;
            }
            else if (type === 'webgl' || type === 'experimental-webgl') {
                if (this._2dContext || this._webgl2Context) {
                    return null;
                }
                if (!this._webglContext) {
                    this._webglContext = new TNSWebGLRenderingContext_1.TNSWebGLRenderingContext(this._canvas.getContext('webgl', getNativeOptions(glOpts)));
                    this._webglContext._canvas = this;
                }
                else {
                    this._canvas.getContext('webgl', getNativeOptions(glOpts));
                }
                this._webglContext._type = 'webgl';
                return this._webglContext;
            }
            else if (type &&
                (type === 'webgl2' || type === 'experimental-webgl2')) {
                if (this._2dContext || this._webglContext) {
                    return null;
                }
                if (!this._webgl2Context) {
                    this._webgl2Context = new TNSWebGL2RenderingContext_1.TNSWebGL2RenderingContext(this.android.getContext('webgl2', getNativeOptions(glOpts)));
                    this._webgl2Context._canvas = this;
                }
                else {
                    this.android.getContext('webgl2', getNativeOptions(glOpts));
                }
                this._webgl2Context._type = 'webgl2';
                return this._webgl2Context;
            }
        }
        return null;
    };
    TNSCanvas.prototype.getBoundingClientRect = function () {
        var view = this;
        var nativeView = view.android;
        var width = this.width;
        var height = this.height;
        return {
            bottom: nativeView.getBottom(),
            height: height,
            left: nativeView.getLeft(),
            right: nativeView.getRight(),
            top: nativeView.getTop(),
            width: width,
            x: nativeView.getX(),
            y: nativeView.getY(),
        };
    };
    return TNSCanvas;
}(canvas_plugin_common_1.TNSCanvasBase));
exports.TNSCanvas = TNSCanvas;
//# sourceMappingURL=TNSCanvas.android.js.map