"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
var TNSDOMMatrix_1 = require("./TNSDOMMatrix");
var canvas_plugin_common_1 = require("./canvas-plugin.common");
var TNSCanvasRenderingContext2D_1 = require("./TNSCanvasRenderingContext2D");
var TNSWebGLRenderingContext_1 = require("./TNSWebGLRenderingContext");
var TNSWebGL2RenderingContext_1 = require("./TNSWebGL2RenderingContext");
function createSVGMatrix() {
    return new TNSDOMMatrix_1.TNSDOMMatrix(Canvas.createSVGMatrix());
}
exports.createSVGMatrix = createSVGMatrix;
__export(require("./canvas-plugin.common"));
var TNSCanvas = (function (_super) {
    __extends(TNSCanvas, _super);
    function TNSCanvas() {
        var _this = _super.call(this) || this;
        _this.useMetal = false;
        _this._didPause = false;
        _this._isReady = false;
        _this._iosOverflowSafeArea = false;
        _this._canvas = Canvas.alloc().initWithFrameUseGL(CGRectZero, !_this.useMetal);
        return _this;
    }
    Object.defineProperty(TNSCanvas.prototype, "ios", {
        get: function () {
            return this._canvas;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvas.prototype, "clientWidth", {
        get: function () {
            return this.width;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvas.prototype, "clientHeight", {
        get: function () {
            return this.height;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvas.prototype, "width", {
        get: function () {
            var measuredWidth = this.getMeasuredWidth();
            if (measuredWidth > 0) {
                return measuredWidth;
            }
            return this._realSize.width;
        },
        set: function (value) {
            this.style.width = value;
            if (this._isCustom) {
                this._layoutNative();
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvas.prototype, "height", {
        get: function () {
            var measuredHeight = this.getMeasuredHeight();
            if (measuredHeight > 0) {
                return measuredHeight;
            }
            return this._realSize.height;
        },
        set: function (value) {
            this.style.height = value;
            if (this._isCustom) {
                this._layoutNative();
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvas.prototype, "iosOverflowSafeArea", {
        get: function () {
            return this._iosOverflowSafeArea;
        },
        set: function (value) {
            var window = UIApplication.sharedApplication.windows[0];
            var topPadding = window.safeAreaInsets.top;
            var bottomPadding = window.safeAreaInsets.bottom;
            if (bottomPadding === 0) {
                this._iosOverflowSafeArea = false;
            }
            else {
                this._iosOverflowSafeArea = value;
            }
        },
        enumerable: true,
        configurable: true
    });
    TNSCanvas.createCustomView = function () {
        var canvas = new TNSCanvas();
        canvas._isCustom = true;
        canvas.width = 300;
        canvas.height = 150;
        return canvas;
    };
    TNSCanvas.prototype.createNativeView = function () {
        return this._canvas;
    };
    TNSCanvas.prototype.flush = function () {
        if (this.ios) {
            this.ios.flush();
        }
    };
    TNSCanvas.prototype.onUnloaded = function () {
        this.ios.pause();
        this._didPause = true;
        _super.prototype.onUnloaded.call(this);
    };
    TNSCanvas.prototype.onLoaded = function () {
        _super.prototype.onLoaded.call(this);
        if (this._didPause) {
            this.ios.resume();
            this._didPause = false;
        }
    };
    TNSCanvas.prototype.onLayout = function (left, top, right, bottom) {
        _super.prototype.onLayout.call(this, left, top, right, bottom);
        if (!this._isReady) {
            this._readyEvent();
            this._isReady = true;
        }
    };
    TNSCanvas.prototype.disposeNativeView = function () {
        this.off('touch, pan', this._touchEvents);
        _super.prototype.disposeNativeView.call(this);
    };
    TNSCanvas.prototype._layoutNative = function () {
        if (!this.parent) {
            if ((typeof this.style.width === 'string' && this.style.width.indexOf('%')) ||
                (typeof this.style.height === 'string' && this.style.height.indexOf('%'))) {
                return;
            }
            if (!this._isCustom) {
                return;
            }
            var size = this._realSize;
            if (!(size.width || 0) && !(size.height || 0)) {
                return;
            }
            var frameSize = this._canvas.frame.size;
            var frame_origin = this._canvas.frame.origin;
            var frame = CGRectMake(frame_origin.x, frame_origin.y, canvas_plugin_common_1.layout.toDeviceIndependentPixels(size.width || 0), canvas_plugin_common_1.layout.toDeviceIndependentPixels(size.height || 0));
            this._canvas.frame = frame;
        }
    };
    TNSCanvas.prototype.getContext = function (type, options) {
        var glOpts = options || {
            alpha: true,
            antialias: true,
            depth: true,
            failIfMajorPerformanceCaveat: false,
            powerPreference: "default",
            premultipliedAlpha: true,
            preserveDrawingBuffer: false,
            stencil: false,
            desynchronized: false
        };
        var canvasOpts = options || {
            alpha: true
        };
        if (type && type === '2d') {
            if (this._webglContext || this._webgl2Context) {
                return null;
            }
            if (!this._2dContext) {
                this._2dContext = new TNSCanvasRenderingContext2D_1.TNSCanvasRenderingContext2D(this._canvas.getContextWithTypeContextAttributes(type, canvasOpts));
                this._2dContext._canvas = this;
            }
            else {
                this._canvas.getContextWithTypeContextAttributes(type, canvasOpts);
            }
            this._2dContext._type = '2d';
            return this._2dContext;
        }
        else if (type && (type === 'webgl' || type === 'experimental-webgl')) {
            if (this._2dContext || this._webgl2Context) {
                return null;
            }
            if (!this._webglContext) {
                this._webglContext = new TNSWebGLRenderingContext_1.TNSWebGLRenderingContext(this._canvas.getContextWithTypeContextAttributes('webgl', glOpts));
                this._webglContext._canvas = this;
            }
            else {
                this._canvas.getContextWithTypeContextAttributes('webgl', glOpts);
            }
            this._webglContext._type = 'webgl';
            return this._webglContext;
        }
        else if (type && (type === 'webgl2' || type === 'experimental-webgl2')) {
            if (this._2dContext || this._webglContext) {
                return null;
            }
            if (!this._webgl2Context) {
                this._webgl2Context = new TNSWebGL2RenderingContext_1.TNSWebGL2RenderingContext(this._canvas.getContextWithTypeContextAttributes('webgl2', glOpts));
                this._webgl2Context._canvas = this;
            }
            else {
                this._canvas.getContextWithTypeContextAttributes('webgl2', glOpts);
            }
            this._webgl2Context._type = 'webgl';
            return this._webgl2Context;
        }
        return null;
    };
    TNSCanvas.prototype.toDataURL = function (type, encoderOptions) {
        if (type === void 0) { type = 'image/png'; }
        if (encoderOptions === void 0) { encoderOptions = 0.92; }
        return this._canvas.toDataURLWithTypeFormat(type, encoderOptions);
    };
    TNSCanvas.prototype.getBoundingClientRect = function () {
        var view = this;
        var frame = view.ios.frame;
        var width = view.width;
        var height = view.height;
        return {
            bottom: height,
            height: height,
            left: frame.origin.x,
            right: width,
            top: frame.origin.y,
            width: width,
            x: frame.origin.x,
            y: frame.origin.y,
        };
    };
    return TNSCanvas;
}(canvas_plugin_common_1.TNSCanvasBase));
exports.TNSCanvas = TNSCanvas;
//# sourceMappingURL=TNSCanvas.ios.js.map