"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var view_1 = require("@nativescript/core/ui/core/view");
var TNSPath2D_1 = require("../TNSPath2D");
var SVGItem_1 = require("./SVGItem");
var CanvasGradient_1 = require("../CanvasGradient");
exports.cxProperty = new view_1.Property({
    name: 'cx'
});
exports.cyProperty = new view_1.Property({
    name: 'cy'
});
exports.rProperty = new view_1.Property({
    name: 'r'
});
var Circle = (function (_super) {
    __extends(Circle, _super);
    function Circle() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Circle.prototype.handleValues = function (canvas) {
        var ctx;
        if (canvas) {
            ctx = canvas.getContext('2d');
        }
        else {
            ctx = this._canvas.getContext('2d');
        }
        var circle = new TNSPath2D_1.TNSPath2D();
        circle.arc(this.cx, this.cy, this.r, 0, 2 * Math.PI);
        ctx.save();
        ctx.lineWidth = this.strokeWidth;
        ctx.globalAlpha = this._realOpacity;
        var lastOpacity;
        if (this._doFillOpacity()) {
            lastOpacity = ctx.globalAlpha;
            ctx.globalAlpha = this._realFillOpacity;
        }
        if (this._doFill()) {
            if (this.fill !== undefined && this.fill !== 'none') {
                if (this.fill && this.fill.indexOf('url') > -1) {
                    var fill = this._getViewById(this.fill);
                    if (fill) {
                        var style = fill._getFillOrStrokeStyle();
                        if (style instanceof CanvasGradient_1.CanvasGradient) {
                            if (typeof fill.gradientTransform === 'string' && fill.gradientTransform.indexOf('rotate')) {
                                var rotation = parseInt(fill.gradientTransform.replace('rotate(', '').replace(')', ''));
                                if (!isNaN(rotation)) {
                                    ctx.rotate(rotation);
                                }
                            }
                            ctx.fillStyle = style;
                        }
                        else {
                            ctx.fillStyle = ctx.createPattern(style, 'repeat');
                        }
                    }
                }
                else {
                    ctx.fillStyle = this.fill;
                }
            }
            ctx.fill(circle);
        }
        if (lastOpacity !== undefined) {
            ctx.globalAlpha = lastOpacity;
        }
        if (this._doStroke()) {
            if (this.stroke !== undefined && this.stroke !== 'none') {
                if (this.stroke && this.stroke.indexOf('url') > -1) {
                    var stroke = this._getViewById(this.stroke);
                    if (stroke) {
                        var style = stroke._getFillOrStrokeStyle();
                        if (stroke instanceof CanvasGradient_1.CanvasGradient) {
                            ctx.strokeStyle = style;
                        }
                        else {
                            ctx.strokeStyle = ctx.createPattern(style, 'repeat');
                        }
                    }
                }
                else {
                    ctx.strokeStyle = this.stroke;
                }
            }
            ctx.stroke(circle);
        }
        ctx.restore();
    };
    return Circle;
}(SVGItem_1.SVGItem));
exports.Circle = Circle;
exports.cxProperty.register(Circle);
exports.cyProperty.register(Circle);
//# sourceMappingURL=Circle.js.map