"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var SVGItem_1 = require("./SVGItem");
var core_1 = require("@nativescript/core");
var b64Extensions = {
    "/": "jpg",
    i: "png",
    R: "gif",
    U: "webp",
};
function b64WithoutPrefix(b64) {
    return b64.split(",")[1];
}
function getMIMEforBase64String(b64) {
    var input = b64;
    if (b64.includes(",")) {
        input = b64WithoutPrefix(b64);
    }
    var first = input.charAt(0);
    var mime = b64Extensions[first];
    if (!mime) {
        throw new Error("Unknown Base64 MIME type: " + b64);
    }
    return mime;
}
var Image = (function (_super) {
    __extends(Image, _super);
    function Image() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.xlink = {};
        return _this;
    }
    Image.prototype.handleValues = function (canvas) {
        var ctx;
        if (canvas) {
            ctx = canvas.getContext('2d');
        }
        else {
            ctx = this._canvas.getContext('2d');
        }
        var src;
        if (this.xlink && this.xlink.href) {
            src = this.xlink.href;
        }
        if (this.href) {
            src = this.href;
        }
        ctx.save();
        if (typeof src === 'string') {
            if (this.isBase64(src)) {
                var nativeImage = this.loadSrc(src);
                if (nativeImage) {
                    ctx.drawImage(nativeImage, 0, 0, this.width, this.height);
                }
            }
        }
        ctx.restore();
    };
    Image.prototype.isBase64 = function (src) {
        return typeof src === "string" &&
            src.startsWith &&
            src.startsWith("data:");
    };
    Image.prototype.loadSrc = function (src) {
        if (typeof src === "string" &&
            src.startsWith &&
            src.startsWith("data:")) {
            var base64result = src.split(",")[1];
            if (!base64result) {
                return null;
            }
            try {
                if (core_1.isIOS) {
                    return UIImage.imageWithData(NSData.alloc().initWithBase64EncodedStringOptions(base64result, 0));
                }
                else {
                    var bytes = android.util.Base64.decode(base64result, android.util.Base64.DEFAULT);
                    return android.graphics.BitmapFactory.decodeByteArray(bytes, 0, bytes.length);
                }
            }
            catch (error) {
                return null;
            }
        }
        return null;
    };
    return Image;
}(SVGItem_1.SVGItem));
exports.Image = Image;
//# sourceMappingURL=Image.js.map